@@ -12,19 +12,18 @@
 #include <X11/Xlib.h>
 #include <X11/XKBlib.h>
 #include "type.h"
-
-static pthread_mutex_t mutex = PTHREAD_MUTEX_INITIALIZER;
+#include "x11_mutex.h"
 
 int
 set_keyboard_repeat(int repeated, unsigned int delay, unsigned int interval)
 {
-    pthread_mutex_lock(&mutex);
+    pthread_mutex_lock(&x11_global_mutex);
     setErrorHandler();
 
     Display *disp = XOpenDisplay(0);
     if (!disp) {
         fprintf(stderr, "Open display failed\n");
-        pthread_mutex_unlock(&mutex);
+        pthread_mutex_unlock(&x11_global_mutex);
         return -1;
     }
 
@@ -49,7 +48,7 @@ set_keyboard_repeat(int repeated, unsigned int delay, unsigned int interval)
     XSync(disp, False);
     XCloseDisplay(disp);
 
-    pthread_mutex_unlock(&mutex);
+    pthread_mutex_unlock(&x11_global_mutex);
 
     return ret;
 }
